@@ -17,11 +17,11 @@ Weather::Meteo - Interface to L<https://open-meteo.com> for historical weather d
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 =head1 SYNOPSIS
 
@@ -144,13 +144,15 @@ Accessor method to get and set UserAgent object used internally. You
 can call I<env_proxy> for example, to get the proxy information from
 environment variables:
 
-    $geo_coder->ua()->env_proxy(1);
+    $meteo->ua()->env_proxy(1);
 
 You can also set your own User-Agent object:
 
+    use LWP::UserAgent::Throttled;
+
     my $ua = LWP::UserAgent::Throttled->new();
-    $ua->throttle('geocoder.ca' => 1);
-    $geo_coder->ua($ua);
+    $ua->throttle('open-meteo.com' => 1);
+    $meteo->ua($ua);
 
 =cut
 
